# UI/UX Feedback

**ID:** Feedback-20260222-133736
**URL:** http://127.0.0.1:5858/
**Date:** 2026-02-22 13:37:58

## Selected Elements



## Feedback

when creating workflow, it says network error, but the network is good

## Screenshot

![Screenshot](./page-screenshot.png)
